@@ -719,7 +719,7 @@ class Builder(Update):
         """
         Выполнить очистку системы от лишних пакетов
         """
-        deo = self.get_default_emerge_opts()
+        deo = self.get_default_emerge_opts(depclean=True)
         chroot_path = self.clVars.Get('cl_builder_path')
         logfile = self._get_log_file()
         with EmergeParser(self.chrootize(chroot_path, EmergeCommand(
@@ -1451,11 +1451,11 @@ class Builder(Update):
             process_func = partial(process_func, "/usr/bin/linux32")
         return partial(process_func, chroot_cmd)
 
-    def get_default_emerge_opts(self):
+    def get_default_emerge_opts(self, depclean=False):
         dv = self.clVars.Get('builder.cl_builder_linux_datavars')
         if dv:
             deo = dv.Get('cl_emerge_default_opts')
-            if dv.GetBool('update.cl_update_with_bdeps_set'):
+            if depclean and dv.GetBool('update.cl_update_with_bdeps_set'):
                 bdeps = " --with-bdeps=y"
             else:
                 bdeps = " --with-bdeps=n"
